package MT::Plugin::mthtmllint;
;#	mthtmllint - HTML lint check for MovableType w/ BigPAPI
;#			Programmed by Piroli YUKARINOMIYA (MAGICVOX)
;#			Open MagicVox.net - http://www.magicvox.net/
;#			@see http://www.magicvox.net/archive/2006/03092330.php

use strict;
use htmllint;
;#use Data::Dumper;#DEBUG

use vars qw( $MYNAME $VERSION );
$MYNAME = 'mthtmllint';
$VERSION = '0.90';

use base qw( MT::Plugin );
my $plugin = new MT::Plugin ({
		name => $MYNAME,
		version => $VERSION,
		author_name => 'Piroli YUKARINOMIYA',
		author_link => 'http://www.magicvox.net/home.php',
		doc_link => 'http://www.magicvox.net/archive/2006/03092330.php',
		description => <<HTMLHEREDOC,
Easy checking the input text with
<a href="http://openlab.ring.gr.jp/k16/htmllint/">Another HTML-lint</a> ver.$htmllint::VERSION,<br />
which is the achieved work by ISHINO Keiichiro. Thanks!
HTMLHEREDOC
});
MT->add_plugin ($plugin);
add_plugin_action ();

sub instance { $plugin }



use constant CALLBACK_PRIORITY =>       1;
use constant TEMPLATE_NAME =>           'mthtmllint Entry Template';
use constant HTMLLINT_INPUT_PAGE =>     'mthtmllint_input.html';
use constant HTMLLINT_RESULT_PAGE =>    'mthtmllint_result.txt';


;### Add plugin actions onto the entry editing page
sub add_plugin_action {
	MT->add_plugin_action ('entry', HTMLLINT_INPUT_PAGE, <<HTMLHEREDOC);
$MYNAME $VERSION : See <b>INPUT</b> page used in the last htmllint checking.
HTMLHEREDOC

	MT->add_plugin_action ('entry', HTMLLINT_RESULT_PAGE, <<HTMLHEREDOC);
$MYNAME $VERSION : See <b>RESULT</b> page of the last htmllint checking.
HTMLHEREDOC
}


;### MT::Entry::pre_save Event Callback
MT::Entry->add_callback ("pre_save", CALLBACK_PRIORITY, $plugin, \&pre_save_callback);
sub pre_save_callback {
	my ($cb, $entry, $original_entry) = @_;
	return 1 if $entry->status != 16;
;#
	;# Load a module template text for the container of input text.
	require MT::Template;
	my $tmpl = MT::Template->load({ blog_id => $entry->blog_id, name => TEMPLATE_NAME });
	return $cb->error ("Couldn't load the module template - ". TEMPLATE_NAME)
		unless $tmpl;

	;# Replace the virtual tags into the each data
	my $entry_title = $entry->title;
	my $text_body = $entry->text;
	my $text_more = $entry->text_more;
	my $entry_excerpt = $entry->excerpt;
	my $entry_keywords = $entry->keywords;
	if ($entry->convert_breaks) {
		$text_body =~ s/\n/<br \/>\n/ig;
		$text_more =~ s/\n/<br \/>\n/ig;
	}
	my $tmpl_text = $tmpl->text;
	$tmpl_text =~ s/<\$?MTEntryTitle\$?>/$entry_title/ig;
	$tmpl_text =~ s/<\$?MTEntryBody\$?>/$text_body/ig;
	$tmpl_text =~ s/<\$?MTEntryMore\$?>/$text_more/ig;
	$tmpl_text =~ s/<\$?MTEntryExcerpt\$?>/$entry_excerpt/ig;
	$tmpl_text =~ s/<\$?MTEntryKeywords\$?>/$entry_keywords/ig;

	;# Create a temporary file
	my $tmp = $cb->{plugin}->{full_path}. '/'. HTMLLINT_INPUT_PAGE;
	return $cb->error ("Couldn't create input file - $tmp")
		unless open FILE, ">$tmp";
	print FILE $tmpl_text;
	close FILE;

	;# Do htmllint
	my $htmllint = $cb->{plugin}->{full_path}. '/lib/htmllint';
	my $result = $cb->{plugin}->{full_path}. '/'. HTMLLINT_RESULT_PAGE;
	if (open FILE, ">$result") {
		;# my poor tech. orz
		my $ret = `perl $htmllint -w short $tmp`;
		print FILE $ret;
		close FILE;
	}

	;# Stay HOLD
	$entry->status (MT::Entry::HOLD);
}


;### BigPAPI Modification Callback
MT->add_callback ('bigpapi::template::edit_entry', CALLBACK_PRIORITY, $plugin, \&edit_entry);
sub edit_entry {
	my ($cb, $app, $template) = @_;
;#
	my $old = quotemeta (<<HTMLHEREDOC);
<option value="1"<TMPL_IF NAME="STATUS_DRAFT"> selected="selected"</TMPL_IF>><MT_TRANS phrase="Unpublished"></option>
HTMLHEREDOC
	my $new = <<HTMLHEREDOC;
<option value="1"><MT_TRANS phrase="Unpublished"></option>
<option value="16"<TMPL_IF NAME="STATUS_DRAFT"> selected="selected"</TMPL_IF>><MT_TRANS phrase="unpublished"> (htmllint)</option>
HTMLHEREDOC
	$$template =~ s/$old/$new/g;
}

1;